==> hledger-1.14.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.14.2
id: hledger-1.14.2-8O7QEYxZk4HKQXWEhCSvXw
key: hledger-1.14.2-8O7QEYxZk4HKQXWEhCSvXw
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
abi: 67b0176224a10e5c513b3836507a9b85
exposed: True
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version
hidden-modules: Paths_hledger
import-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-1.14.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/hledger-1.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.14.2-8O7QEYxZk4HKQXWEhCSvXw
depends:
    Decimal-0.5.1-HbE7jjGKIya5lM4gHWrRW6
    Diff-0.3.4-C6Bl1un4oiiBWGaHLlh5bu
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP base-4.12.0.0
    base-compat-batteries-0.10.5-B7OiQ1YKRSjGxdF9TPzjKz
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    directory-1.3.3.0 easytest-0.2.1-AISBMewPCVmGe5DrRfEMpv
    filepath-1.4.2.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskeline-0.7.4.3 hledger-lib-1.14.1-3Inz9YMmAPF2rzPAC0nsRE
    lucid-2.9.11-D93PzxqIdhrKI258xnxkGo
    math-functions-0.3.1.0-2nHUjHLEI0SLJ3iUlVSM3j
    megaparsec-7.0.4-1CpsR9z4yywE3fIGM7EYlI mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 process-1.6.5.0
    regex-tdfa-1.2.3.1-KcIcA5zjtfPBFphuPbNC37
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-8cbxhuMjKn3HmvHi12NufK
    split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb
    temporary-1.3-2R9bhTuduqsDRv55IV8XfU terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
    wizards-1.0.3-LeWouXF9w2V7cw8M1LVGLS
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hledger-1.14.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/hledger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger
version: 1.14.2
id: hledger-1.14.2-Hlts5liFdAi9zwvmsewcVz
key: hledger-1.14.2-Hlts5liFdAi9zwvmsewcVz
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Command-line interface for the hledger accounting tool
description:
    This is hledger'\''s command-line interface.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance, Console
abi: fbeb4381813d8adf399fcbb563349768
exposed: True
exposed-modules:
    Hledger.Cli Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Balance
    Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Checkdates
    Hledger.Cli.Commands.Checkdupes Hledger.Cli.Commands.Close
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Files
    Hledger.Cli.Commands.Help Hledger.Cli.Commands.Import
    Hledger.Cli.Commands.Incomestatement Hledger.Cli.Commands.Prices
    Hledger.Cli.Commands.Print Hledger.Cli.Commands.Printunique
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Registermatch
    Hledger.Cli.Commands.Rewrite Hledger.Cli.Commands.Roi
    Hledger.Cli.Commands.Stats Hledger.Cli.Commands.Tags
    Hledger.Cli.CompoundBalanceCommand Hledger.Cli.DocFiles
    Hledger.Cli.Main Hledger.Cli.Utils Hledger.Cli.Version
hidden-modules: Paths_hledger
import-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hledger-1.14.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hledger
hs-libraries: HShledger-1.14.2-Hlts5liFdAi9zwvmsewcVz
depends:
    Decimal-0.5.1-8Mt0U2LQbMVKTwH0J7VeMC
    Diff-0.3.4-C6Bl1un4oiiBWGaHLlh5bu
    ansi-terminal-0.8.2-IytGdmUG1lK1dAjqEeG5cq base-4.12.0.0
    base-compat-batteries-0.10.5-GzsckdFcIWa1B4xxVyaZ9i
    bytestring-0.10.8.2 cmdargs-0.10.20-HFOpHQTj4XE8aEWjoI1u1
    containers-0.6.0.1 data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    directory-1.3.3.0 easytest-0.2.1-AISBMewPCVmGe5DrRfEMpv
    filepath-1.4.2.1 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    haskeline-0.7.4.3 hledger-lib-1.14.1-Jf9UfZyLEZK9dwdWwDYHEj
    lucid-2.9.11-58CfyYm1sYtDSgnVIGZ3yd
    math-functions-0.3.1.0-GW8vg3sPECY78WvUCbZJWc
    megaparsec-7.0.5-LbhLLsrUoh4Eo2xJp0Opc2 mtl-2.2.2
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8 process-1.6.5.0
    regex-tdfa-1.2.3.2-1zrqdepzFAcLwdkKMIY7hi
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji
    shakespeare-2.0.20-HMiBKwyKq2rB8aTGI4QQIz
    split-0.2.3.3-DmDMlgWSMW26OczFIiZ5Gr
    tabular-0.2.2.7-FYVnBEx3xwsDpJzPJOu9nb
    temporary-1.3-5cWlygi8YnlCS3tuKAJyz3 terminfo-0.4.1.2 text-1.2.3.1
    time-1.8.0.2 transformers-0.5.6.2
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
    wizards-1.0.3-LeWouXF9w2V7cw8M1LVGLS
haddock-interfaces: /usr/share/doc/hledger/html/hledger.haddock
haddock-html: /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
